==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reinizializza',
	'boxstr_close' => 'Chiudi',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Finestra di dialogo',
	'boxstr_dialog_title_medias' => 'Visualizzazione di un media',
	'boxstr_loading' => 'Caricamento in corso…',
	'boxstr_next' => 'Prossimo',
	'boxstr_press_escape_to_close' => 'Premere "ESC" per interrompere',
	'boxstr_previous' => 'Precedente',
	'boxstr_slideshowStart' => 'Presentazione',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Specificare l’elemento target che attiverà il box. (CSS expression o  jQuery)',
	'explication_selecteur_galerie' => 'Specificare l’elemento target da da raggruppare insieme nella galleria. (jQuery o CSS expression)',
	'explication_splash_url' => 'Inserisci l’URL dei media da visualizzare automaticamente in un box alla prima visita del sito pubblico.',
	'explication_traiter_toutes_images' => 'Inserire un box attorno a tutte le immagini?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Default scuro',
	'info_box_lity_nom_skin__simple_white' => 'Default chiaro',
	'info_box_lity_nom_skin_fancybox' => 'Modalità "Fancybox"',
	'info_box_lity_nom_skin_thickbox' => 'Modalità "Thickbox"',

	// L
	'label_active' => 'Attivare il mediabox nel sito pubblico',
	'label_apparence' => 'Apparenza',
	'label_aucun_style' => 'Non usare una cornice per impostazione predefinita',
	'label_choix_transition_elastic' => 'Elastico',
	'label_choix_transition_fade' => 'Sfuma',
	'label_choix_transition_none' => 'Senza effetti di transizione',
	'label_defaultcaptionstate' => 'Didascalia dell’immagine',
	'label_defaultcaptionstate_expanded' => 'Completare',
	'label_defaultcaptionstate_min' => 'Abbreviato',
	'label_maxheight' => 'Altezza massima (% o px)',
	'label_maxwidth' => 'Larghezza massima (% o px)',
	'label_minheight' => 'Altezza minima (% o px)',
	'label_minwidth' => 'Larghezza minima (% o px)',
	'label_opacite' => 'Opacità dello sfondo',
	'label_selecteur_commun' => 'In generale',
	'label_selecteur_galerie' => 'Nella galleria',
	'label_skin' => 'Aspetto grafico',
	'label_slideshow_speed' => 'Tempo di esposizione delle immagini nella presentazione (ms)',
	'label_speed' => 'Velocità di transizione (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Altezza (% o px)',
	'label_splash_url' => 'URL da mostrare',
	'label_splash_width' => 'Larghezza (% o px)',
	'label_traiter_toutes_images' => 'Immagini',
	'label_transition' => 'Transizione tra due viste',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configurazione del Media Box'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/mediabox/lang/mediabox_it.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/mediabox?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_reinitialiser' => 'Reinizializza',
	'boxstr_close' => 'Chiudi',
	'boxstr_current' => '@current@/@total@',
	'boxstr_dialog_title_default' => 'Finestra di dialogo',
	'boxstr_dialog_title_medias' => 'Visualizzazione di un media',
	'boxstr_loading' => 'Caricamento in corso…',
	'boxstr_next' => 'Prossimo',
	'boxstr_press_escape_to_close' => 'Premere "ESC" per interrompere',
	'boxstr_previous' => 'Precedente',
	'boxstr_slideshowStart' => 'Presentazione',
	'boxstr_slideshowStop' => 'Stop',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Specificare l’elemento target che attiverà il box. (CSS expression o  jQuery)',
	'explication_selecteur_galerie' => 'Specificare l’elemento target da da raggruppare insieme nella galleria. (jQuery o CSS expression)',
	'explication_splash_url' => 'Inserisci l’URL dei media da visualizzare automaticamente in un box alla prima visita del sito pubblico.',
	'explication_traiter_toutes_images' => 'Inserire un box attorno a tutte le immagini?',

	// I
	'info_box_lity_nom_skin__simple_dark' => 'Default scuro',
	'info_box_lity_nom_skin__simple_white' => 'Default chiaro',
	'info_box_lity_nom_skin_fancybox' => 'Modalità "Fancybox"',
	'info_box_lity_nom_skin_thickbox' => 'Modalità "Thickbox"',

	// L
	'label_active' => 'Attivare il mediabox nel sito pubblico',
	'label_apparence' => 'Apparenza',
	'label_aucun_style' => 'Non usare una cornice per impostazione predefinita',
	'label_choix_transition_elastic' => 'Elastico',
	'label_choix_transition_fade' => 'Sfuma',
	'label_choix_transition_none' => 'Senza effetti di transizione',
	'label_defaultcaptionstate' => 'Didascalia dell’immagine',
	'label_defaultcaptionstate_expanded' => 'Completare',
	'label_defaultcaptionstate_min' => 'Abbreviato',
	'label_maxheight' => 'Altezza massima (% o px)',
	'label_maxwidth' => 'Larghezza massima (% o px)',
	'label_minheight' => 'Altezza minima (% o px)',
	'label_minwidth' => 'Larghezza minima (% o px)',
	'label_opacite' => 'Opacità dello sfondo',
	'label_selecteur_commun' => 'In generale',
	'label_selecteur_galerie' => 'Nella galleria',
	'label_skin' => 'Aspetto grafico',
	'label_slideshow_speed' => 'Tempo di esposizione delle immagini nella presentazione (ms)',
	'label_speed' => 'Velocità di transizione (ms)',
	'label_splash' => 'Splash Box',
	'label_splash_height' => 'Altezza (% o px)',
	'label_splash_url' => 'URL da mostrare',
	'label_splash_width' => 'Larghezza (% o px)',
	'label_traiter_toutes_images' => 'Immagini',
	'label_transition' => 'Transizione tra due viste',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configurazione del Media Box',
];
